GoogleSearch_services.GoogleSearchServiceLocator

|  | ## Cheshire3 Object Model: Class GoogleSearchServiceLocator

Module GoogleSearch_services :: Class GoogleSearchServiceLocator

## Class GoogleSearchServiceLocator
source code

Object Tree:

    GoogleSearchServiceInterface --+
                                   |
                                  GoogleSearchServiceLocator

Instance Methods

getGoogleSearchPortAddress(self)
getGoogleSearchPort(self, portAddress=None, **kw)

Class Variables

GoogleSearchPort_address |

Method Details

### getGoogleSearchPortAddress(self) | source code

### getGoogleSearchPort(self, portAddress=None, **kw) | source code
Overrides: GoogleSearchServiceInterface.getGoogleSearchPort

Class Variable Details

    ### GoogleSearchPort_address Value:
        'http://api.google.com/search/beta2'